@@ -1,6 +1,7 @@
 // 3/5/2008 version 0.02 [added item 10]
 // 18/5/2008 version 0.03 [added item 11]
 // 19/5/2008 version 0.04 [added item 12,13,14,15]
+// 12/2012 version 0.05 [added item 16...26]
 // this is all very premature !!! The naming needs to be adapted to f1,f2...f20
 
 //  1 science(t)	checks scientific notation 4e+4 --> 4*10^4		: returns modified t or "error"
@@ -30,7 +31,16 @@
 // 15 upper_f(t)	converts all 'known' functions and 'and' to uppercase	: returns modified t or "error"
 // 16 is_number(t)	checks if no text is present				: returns 0 or 1  (0=error,1=success)
 // 17 is_real_number(t)	checks if real number: no sqrt or e+ allowed			: returns 0 or 1  (0=error,1=success)
-    
+// 18 make_description(list,cnt) converts wims item list into javascript array size "cnt" : returns array(cnt)
+// 19 myConfirm(txt,reply,server,session,module,counter,color) will send answer to server...or not
+// 20 nospace(string) returns string without spaces
+// 21 singlespace(string) returns  string with multiple spaces collapsed (including trailing spaces; eg trim) 
+// 22 word2items(string) returns itemlist (not a js-array ) 1 2 3 -> 1,2,3 
+// 23 rawmath(string) returns modified string 4x -> 4*x  ; 4sin(3pi) -> 4*sin(3*pi)
+// 24 words2string(words,separator) returs modified string 1 2 3 --> 1:2:3 or 1@2@3 
+// 25 wordcnt(string) || wordcount(string) returns amount of words " A   B  ABC     " = 3  [a space is not a word]
+// 26 is_text(string) returns 0 if number are present in text
+
 function SetTexAppSize(){
     if( document.getElementById('TexApp1') ){ // starts with 1 !!!!
 	var p = 1;var xsize,ysize;
@@ -38,54 +48,70 @@ function SetTexAppSize(){
     	    try{
     		xsize = document.getElementById('TexApp'+p).getPrefferedWidth();
     		ysize = document.getElementById('TexApp'+p).getPrefferedHeight();
-		document.getElementById('TexApp'+p).width = xsize;                                                                             
+		document.getElementById('TexApp'+p).width = xsize;
     		document.getElementById('TexApp'+p).height = ysize;
 		p++;
-	    }catch(e){setAlarm("Your browser does not support resizing of the applet.<br>Opera is known to have some trouble with this.<br>Firefox,Internet Explorer,Google-chrome<br>or even Safari may be a good choice.");return;}// problems on opera (bug)
+	    }catch(e){setAlarm("The resizing of the applet went wrong...<br />May be your java \"virtual machine\" is very slow in starting up...<br />Try a reload on the page ...<br />or try a different -more recent- browswer<br />Use the Oracle / SUN java plugin...the \"OpenJDK plugin (icedtea)\" is known to have some serious problems");return;}// problems on opera (bug)
 	}
 	if(document.getElementById('wait_for_applet')){
 	    document.getElementById('wait_for_applet').style.display = "none"; 
 	}
-    }                                                 
+    }
 }
 
 function setAlarm(txt){
-    var h=document.documentElement.clientHeight;
-    var w=document.documentElement.clientWidth;
+    var h = parseInt( (document.documentElement.clientHeight)/2);
+    var w = parseInt( (document.documentElement.clientWidth)/2 - 200);
+    document.getElementById('alarmtext').style.top = h+'px';
+    document.getElementById('alarmtext').style.left = w+'px';
     document.getElementById('alarmtext').style.display = "block"
-    document.getElementById('alarmtext').style.top = h/3.5;
-    document.getElementById('alarmtext').style.left =w/4;
-    document.getElementById('alarmtext').innerHTML='<table cellpadding=\"10\"><tr><th>'+txt+'</th></tr></table>';
+    document.getElementById('alarmtext').innerHTML=txt;
+    window.scrollTo(w,h-120);
     setTimeout('resetAlarm()',4000);
 }
-	
+
+function myConfirm(txt,reply,server,session,module,counter,color){
+    reply=encodeURIComponent(reply);
+//    reply = reply.replace(/'/g,'%22'); // need to replace '  
+    reply = reply.replace(/'/g,"\\'"); // need to escape " 
+    var h = parseInt( (document.documentElement.clientHeight)/2);
+    var w = parseInt( (document.documentElement.clientWidth)/2 - 200);
+    document.getElementById('alarmtext').style.top = h+'px';
+    document.getElementById('alarmtext').style.left = w+'px';
+    document.getElementById('alarmtext').style.display = "block";
+    window.scrollTo(w,h-120);
+    document.getElementById('alarmtext').innerHTML=r0+'<br /><span style=\"color:red\"><tt>'+txt+'</tt></span><br />'+"<input type=\"button\" id=\"schaersvoorde_confirm_ok_button\" value="+r45+" onclick=\"javascript:document.getElementById(\'schaersvoorde_exercise\').setAttribute(\'style\',\'background-color:"+color+"\');document.location.href = \'"+server+"?session="+session+"&module="+module+"&cmd=reply&reply"+counter+"="+reply+"\';\" />&nbsp;&nbsp;<input type=\"button\" id=\"schaersvoorde_confirm_nok_button\" value="+r46+" onclick=\"javascript:resetAlarm()\" \>"
+}
+
 function resetAlarm(){
-    document.getElementById('alarmtext').style.display = "none"
+    document.getElementById('alarmtext').style.display = "none";
 }
 
 function science(t){// corrected: startvalue+3 != startvalu*10^3 :)
     t=t.replace(/\*\*/g,'^'); 
     t=t.replace(/x10/g,'*10')
     e=t.indexOf('e');
-    cc=['0','1','2','3','4','5','6','7','8','9'];
-    var c0;var c1;var t0;var t1;var c;var a;var trouble=0;var s;
-    while(e!=-1){
-	t0=t.charAt(e-1);
-	t1=t.charAt(e+1);
-	t2=t.charAt(e+2);
-	c0=0;c1=0;
-	for(s=0;s<10;s++){a=cc[s];if(t0==a){c0=1;}}
-	for(s=0;s<10;s++){a=cc[s];if(t1==a){c1=1;}}
-	if(c0==1 && c1==1){t=t.replace('e','*10^');}
-	if(c0==1 && c1==0 && t1=="+"){t=t.replace('e+','*10^');}
-	if(c0==1 && c1==0 && t1=="-"){t=t.replace('e-','*10^-');}
-	if(c0==1 && c1==0 && t1==""){t=t.replace('e','E');}
-	t=t.replace('e','E');
-	e=t.indexOf('e');
-	trouble++;if(trouble>100){setAlarm(r20);t="error";return t;}
+    if(e != -1){
+	cc=['0','1','2','3','4','5','6','7','8','9'];
+	var c0;var c1;var t0;var t1;var c;var a;var trouble=0;var s;
+	while(e!=-1){
+	    t0=t.charAt(e-1);
+	    t1=t.charAt(e+1);
+	    t2=t.charAt(e+2);
+	    c0=0;c1=0;
+	    for(s=0;s<10;s++){a=cc[s];if(t0==a){c0=1;}}
+	    for(s=0;s<10;s++){a=cc[s];if(t1==a){c1=1;}}
+	    if(c0==1 && c1==1){t=t.replace('e','*10^');}
+	    if(c0==1 && c1==0 && t1=="+"){t=t.replace('e+','*10^');}
+	    if(c0==1 && c1==0 && t1=="-"){t=t.replace('e-','*10^-');}
+	    if(c0==1 && c1==0 && t1==""){t=t.replace('e','E');}
+	    t=t.replace('e','E');
+	    e=t.indexOf('e');
+	    trouble++;if(trouble>100){setAlarm(r20);t="error";return t;}
+	}
+	t=t.replace(/E/g,"e");
+	t=t.replace(/10\^0/g,"10^");
     }
-    t=t.replace(/E/g,"e");
-    t=t.replace(/10\^0/g,"10^");
     return t;
 }
 
@@ -391,8 +417,6 @@ function check_s2(t){
     return t;
 }
 
-    
-
 function keywords(t){
     var kwords=[' en ',' et ',' of ',' or ',' ou ',' plus ',' and ','and/or',' & '];
     var a1;t=t.replace(/\~/g,' ');var trouble=0;t=t.toLowerCase();
@@ -424,16 +448,6 @@ function upper_varlist(varlist,t){
     return t;
 }
 
-function rawmath(t){
-    // poor mans rawmath?
-    var functies=['log','ln','abs','sqrt','sin','cos','tan','atan','acos','sinh','cosh','tanh','pi'];
-    return t;
-}
-
-function represent(t){
-    // unicode math display ?
-    return t;
-}
 function arrows(t,arg1,arg2,arg3){
     // modify t in order to have a uniform arrow.
     var ascii_arrows=['volgt','alors','thus','dus','therefor','ergo','<===>','===>','<==>','==>','<=>','=>','<--->','--->','<-->','-->','<->','->'];
@@ -540,6 +554,14 @@ function arrows(t,arg1,arg2,arg3){
     setAlarm("syntax error in function <br> arrows(t,arg1,arg2,arg3)<br> t is answer <br> arg1=switch, arg1=0: converts ascii arrows to unified \"->\" <br> arg1=1 : converts ascii arrows to unified \"\u2192\" <br> arg1=2 : returns no arrows ,just the text after the last arrow<br> arg1=3 : returns no arrows...the answer is an array <br> arg1=4 : returns the answer ,checks on all steps<br> arg2=variable name<br>arg3=amount if any of arrows...");
 }
 
+function is_text(t){
+    if(t.length == 0 || t == " "){setAlarm(r44);return 0;}
+    var tt=t.toLowerCase();
+    tt = nospace(tt);
+    tt = tt.replace(/[a-z]/g,'');
+    if(tt.length != 0 ){setAlarm("<b>"+t+"</b>...?<br />"+r47);return 0;}
+}
+
 function is_number(t){
     if(t.length == 0 || t == " "){setAlarm(r44);return 0;}
     t=science(t);
@@ -552,7 +574,7 @@ function is_number(t){
 	s=s.replace(f,F);
     }
     s=s.replace(/[a-z\~\!\@\#\$\&\_\=\:\;]/g,'');
-    if(s.length != t.length){setAlarm(r37+" "+t); return 0;}else{return 1;}
+    if(s.length != t.length){setAlarm(r37+"<br /><b>"+t+"</b>..."); return 0;}else{return 1;}
 }
 
 function is_real_number(t){
@@ -560,6 +582,125 @@ function is_real_number(t){
     t=science(t);
     var s=t.toLowerCase();
     s=s.replace(/[a-z\~\!\@\#\$\&\_\=\:\;]/g,'');
-    if(s.length != t.length){setAlarm(r37+" "+t) ; return 0;}else{return 1;}
+    if(s.length != t.length){setAlarm(r37+"<br /><b>"+t+"</b>...") ; return 0;}else{return 1;}
 }
 
+function make_description(list,cnt){
+    if( cnt == null ){ cnt = 30; }
+    if( list == null ){
+	list = new Array(cnt);
+    }
+    else
+    {
+	list = list.split(',');
+    }
+    for(var p = 0 ; p < cnt ; p++ ){
+	if( list[p] == null ){
+	    list[p] = list[0];
+	}
+    }
+    return list;
+}
+
+function singlespace(list){
+    var c = 0;
+    while(list.indexOf('  ')!=-1){
+	list = list.replace('  ',' ');
+	c++;
+	if(c > 100){return list;}
+    }
+    if( list.charAt(list.length - 1) == ' ' ){
+	list = list.substring(0,list.length-1);
+    }
+    if( list.charAt(0) == ' ' ){
+	list = list.substring(1,list.length);
+    }
+    return list;
+}
+
+function nospace(list){
+    var c = 0;
+    while(list.indexOf(' ')!=-1){
+	list = list.replace(' ','');
+	c++;
+	if(c > 100){return list;}
+    }
+    return list;
+}
+
+function words2items(words){
+    return words2string(words,',');
+}
+
+function words2string(words,separator){
+    words = singlespace(words);
+    var c = 0;
+    while(words.indexOf(' ')!=-1){
+	words = words.replace(' ',separator);
+	c++;
+	if(c > 100){return words;}
+    }
+    return words;
+}
+
+function wordcnt(string){
+    return wordcount(string);
+}
+
+function wordcount(string){
+    if(string.length == 0 ){return 0;}
+    var tmp = singlespace(string);
+    if(tmp.length  === 0 ){ return 0;}// === checks on value and type
+    tmp = tmp.split(' ');
+    return tmp.length;
+}
+
+// not invented here ...
+Array.prototype.listuniq = function() {
+        var o = {}, i, l = this.length, r = [];
+        for(i=0; i<l;i+=1) o[this[i]] = this[i];
+        for(i in o) r.push(o[i]);
+        return r;
+}
+
+function rawmath(i){
+    i=i.toLowerCase();
+    i=i.replace(/\ /g,"");
+    i=i.replace(/\*\*/g,"^");
+    i=i.replace(/\u03c0/g,"pi");i=i.replace(/\u212e/g,"e");
+    if(i.indexOf("e+")!=-1){i=i.replace("e+","*10^");}
+    if(i.indexOf("e-")!=-1){i=i.replace("e-","*10^-");}
+    i=i.replace(/\*\*/g,"*");if(i.charAt(0)=="*"){i=i.substring(1,i.length);}
+    var fun=["asin","acos","atan","sin","cos","tan","log","ln","pi","e","x","y"];
+    var cons=["pi","e","0","1","2","3","4","5","6","7","8","9"];
+    var P;var D;var p;var d;
+    var l=cons.length;var cntl=0;var cntr=0;
+    for(p=0;p<i.length;p++){
+	if(i.charAt(p) == '('){cntl++;}
+	if(i.charAt(p) == ')'){cntr++;}
+    }
+    if(cntl != cntr){i = i+')';}
+    for(p=0;p<fun.length;p++){
+	for(d=0;d<l;d++){
+	    while(i.indexOf(cons[d]+""+fun[p])!=-1){
+		i=i.replace(cons[d]+""+fun[p],cons[d]+"*"+fun[p]);
+	    }
+	    while(i.indexOf(fun[p]+""+cons[d])!=-1){
+		i=i.replace(fun[p]+""+cons[d],fun[p]+"*"+cons[d]);
+	    }
+	}
+    }
+    if(i.indexOf("(")!=-1){
+	for(p=0;p<l;p++){
+	    if(i.indexOf(cons[p]+"(")!=-1){
+		i=i.replace(cons[p]+"(",cons[p]+"*(");
+	    }
+	    if(i.indexOf(")"+cons[p])!=-1){
+		i=i.replace(")"+cons[p],")*"+cons[p]);
+	    }
+	}
+	i=i.replace(/\)\(/g,")*(");
+    }
+    return i;
+}
+    
