@@ -113,6 +113,7 @@ struct {
       {"title_cn",	t_head ,1,	p_title_cn},
       {"title_en",	t_head ,1,	p_title_en},
       {"title_es",	t_head ,1,	p_title_es},
+      {"title_fr",	t_head ,1,	p_title_fr},
       {"title_it",	t_head ,1,	p_title_it},
       {"title_nl",	t_head ,1,	p_title_nl},
       {"title_si",	t_head ,1,	p_title_si},
@@ -171,7 +172,7 @@ long int getinp(char fname[])
 	/* Processes input file */
 void process(void)
 {
-    char *p, *pe, *pp, c;
+    char *p, *pe, *pp;
     int i,j;
     
     for(p=inpbuf,define_no=0;define_no<MAX_DEFINE && p<inpend;p++) {
@@ -199,7 +200,7 @@ void process(void)
 	    if(pp>p) p=pp-1;
 	    continue;
 	}
-	c=*pe; *pe=0;
+	/*c=*pe; */*pe=0;
 	i=search_list(directives,dir_no,sizeof(directives[0]),p);
 	if(i<0) {
 	    if(wordchr(mdef,p)!=NULL) {
