@@ -1132,8 +1132,8 @@ void phtml_put_base(char *fname,int cache)
 	/* Read main.phtml, process it, and write to stdout. */
 void main_phtml_put(char *mname)
 {
-    char *p, buf[1024], txbuf[256], dirnbuf[256], bgbuf[256];
-    char *bcolor, *refcolor, *bg, *tx, *dirn, *vlink, *link;
+    char *p, buf[1024], txbuf[256], dirnbuf[256], bgbuf[256], spfbuf[256];
+    char *bcolor, *refcolor, *bg, *tx, *dirn, *vlink, *link, *spf ;
     define_html_header(); readnest=0;
     nph_header(200);
     p=getvar("wims_backslash_insmath");
@@ -1167,23 +1167,30 @@ void main_phtml_put(char *mname)
     bg=getvar("wims_bgimg"); bgbuf[0]=0;
     if(bg!=NULL && *bg!=0 && strchr(bg,'\"')==NULL) {
 	if(strchr(bg,'/')==NULL)
-	  snprintf(bgbuf,sizeof(bgbuf),"background=\"gifs/bg/%s\"",bg);
+	  snprintf(bgbuf,sizeof(bgbuf),"background-image: url(\"gifs/bg/%s\");",bg);
 	else
-	  snprintf(bgbuf,sizeof(bgbuf),"background=\"%s\"",bg);
+	  snprintf(bgbuf,sizeof(bgbuf),"background-image: url(\"%s\");",bg);
     }
+    setvar("wims_bodyimg",bgbuf);
     tx=getvar("wims_textcolor");
     if(tx!=NULL && *tx!=0 && strchr(tx,'\"')==NULL) {
-	snprintf(txbuf,sizeof(txbuf),"text=\"%s\"",tx);
+	snprintf(txbuf,sizeof(txbuf),"color:%s;",tx);
     }
     else txbuf[0]=0;
+   /* special fonts defined in special_font -should also take the value specialfont in wims.conf */
+    if(spec_font==1){ 
+        spf=getvar("wims_specialfont");
+        if(spf!=NULL && *spf!=0) { snprintf(spfbuf,sizeof(spfbuf),"%s",spf);}
+          else { snprintf(spfbuf,sizeof(spfbuf),"%s",special_font); }
+        setvar("wims_special_font",spfbuf);
+    }
     dirn=getvar("wims_main_dirn");     /* "rtl" for arabic writing ; on pourrait laisser vide pour les autres ? */
     if(dirn!=NULL && *dirn!=0 && strchr(dirn,'\"')==NULL) {
 	snprintf(dirnbuf,sizeof(dirnbuf),"dir=\"%s\"",dirn);
     }
     else dirnbuf[0]=0;
     snprintf(buf,sizeof(buf),
-	     "bgcolor=\"%s\" %s %s %s link=\"%s\" vlink=\"%s\"",
-	     bcolor,txbuf,  bgbuf, dirnbuf,link,vlink);
+	     "class=\"main_body\" %s",dirnbuf);
     setvar("wims_htmlbody",buf);
     phtml_put(mname,0);
 }
