@@ -394,7 +394,7 @@ void cookie2session(void)
     char nbuf[MAX_FNAME+1];
 
     if(mode==mode_popup) return;
-    if(cookiegot[0]==0 || ro_cmd==cmd_close) {
+    if(cookiegot[0]==0) {
 	ckset: cookiegot[0]=0; setcookie=1; return;
     }
     p=getvar("special_parm");
@@ -1148,6 +1148,12 @@ int main(int argc, char *argv[], char *envp[])
 */
     getppid();	/* this is the first sysmask trigger, must be after checklogd() */
     predetermine_language();
+    /* modify a few rlimits for 64-bit processors */
+    if (sizeof(long) == 8) {
+      rlimit_as*=2;    /* virtual memory size */
+      rlimit_data*=2;  /* data segment size; maxima requires a lot */
+      rlimit_stack*=2; /* stack size */
+    }
     set_rlimits();
     init_random();
     module_configure();
